@@ -21,9 +21,11 @@ def infinity_norm(x_vector):
     return max([ abs(x_item) for x_item in x_vector ])
 
 def boltzmann_softmax(x_list, beta):
-    # TODO: Implement the trick to overcome the overflow error
+    # The max x
+    x_max = max(x_list)
 
-    numerator = sum([ np.exp(beta * x) * x for x in x_list ])
-    denominator = sum([ np.exp(beta * x) for x in x_list ])
+    # Divide both the numerator and the denominator by exp(x_max) to overcome the overflow error
+    numerator = sum([ np.exp(beta * (x - x_max)) * x for x in x_list ])
+    denominator = sum([ np.exp(beta * (x - x_max)) for x in x_list ])
 
     return numerator / denominator
